#!/usr/bin/python
import os

from freddist.core import setup
from freddist.command.install import install
from freddist.util import find_packages, findall


PROJECT_NAME = 'fred-whois'


class FredWhoisInstall(install):
    user_options = install.user_options + [
        ('context=', None,
         'CORBA nameservice context name [fred]'),
        ('host=', None,
         'CORBA nameservice host [localhost:2809]'),
        ("idldir=", "d",
         "directory where IDL files reside [PREFIX/share/idl/fred]"),
    ]

    DEPS_PYMODULE = ('simpletal', 'omniORB.CORBA', 'Image')

    def initialize_options(self):
        install.initialize_options(self)
        self.context = None
        self.host = None
        self.idldir = None

    def finalize_options(self):
        install.finalize_options(self)
        if not self.context:
            self.context = 'fred'
        if not self.host:
            self.host = 'localhost:2809'
        if not self.idldir:
            self.idldir = self.expand_filename('$data/share/idl/fred')

    def update_whois_config(self, filename):
        '''Update whois config'''
        content = open(filename).read()
        content = content.replace("ROOT_BASEDIR", self.expand_filename('$data/share/fred_whois'))
        content = content.replace("LOCALSTATEDIR", self.expand_filename('$localstate'))
        content = content.replace("TEMPLATES_BASEDIR", self.expand_filename('$purelib/fred_whois/templates'))
        content = content.replace("SHARE_PACKAGE", self.expand_filename('$purelib/fred_whois'))
        content = content.replace("CORBA_IDL", os.path.join(self.idldir, 'ccReg.idl'))
        content = content.replace("CORBA_HOST", self.host)
        content = content.replace("CORBA_CONTEXT", self.context)
        open(filename, 'w').write(content)
        self.announce("File '%s' was updated" % filename)

    def update_apache_config(self, filename):
        '''Update apache config'''
        content = open(filename).read()
        content = content.replace("INSTALL_PURELIB", self.expand_filename('$purelib/fred_whois'))
        content = content.replace("PYTHON_ROOT", self.expand_filename('$purelib'))
        content = content.replace("SHARE_WWW", self.expand_filename('$purelib/fred_whois/static'))
        open(filename, 'w').write(content)
        self.announce("File '%s' was updated" % filename)

    def update_whois(self, filename):
        content = open(filename).read()
        conf_path = self.expand_filename('$sysconf/fred/whois.conf')
        content = content.replace("config = os.environ.get('WHOIS_CONFIG_FILE' , '/usr/local/etc/fred/whois.conf')",
                                  "config = os.environ.get('WHOIS_CONFIG_FILE' , '%s')" % conf_path)
        open(filename, 'w').write(content)
        self.announce("File '%s' was updated" % filename)

    def update_simple_stats(self, filename):
        content = open(filename).read()
        conf_path = self.expand_filename('$sysconf/fred/whois.conf')
        content = content.replace("config = '/etc/fred/whois.conf'",
                                  "config = '%s'" % conf_path)
        open(filename, 'w').write(content)
        self.announce("File '%s' was updated" % filename)


def main():
    srcdir = os.path.dirname(os.path.abspath(__file__))

    packages = find_packages(srcdir)
    data_files = [
        ('$doc', ['README.txt', 'conf/apache.conf']),
        ('$sysconf/fred', ['conf/whois.conf'])]
    whois_data = ['captcha/pil_missing.jpg', 'templates/*.pt.*'] + \
        [os.path.join('static', f) for f in findall(os.path.join(srcdir, 'fred_whois/static'))]

    setup(name=PROJECT_NAME,
          description='Fred Whois',
          author='David Pospisilik, Zdenek Bohm, CZ.NIC',
          author_email='zdenek.bohm@nic.cz',
          url='http://www.nic.cz/',
          license='GNU GPL',
          platforms=['posix'],
          long_description='The part of the CZ.NIC CMS web framework.',
          scripts=['fred_whois/statistics/simple_stats.py'],
          packages=packages,
          package_data={'fred_whois': whois_data,
                        'fred_whois.CaptchaWhois': ['data/fonts/vera/*.*']},
          i18n_files=['fred_whois/locale/cs_CZ/LC_MESSAGES/whois.po',
                      'fred_whois/locale/en_US/LC_MESSAGES/whois.po',
                      'fred_whois/locale/C/LC_MESSAGES/whois.po'],
          data_files=data_files,
          modify_files={'$sysconf/fred/whois.conf': 'update_whois_config',
                        '$doc/apache.conf': 'update_apache_config',
                        '$purelib/fred_whois/whois.py': 'update_whois',
                        '$scripts/simple_stats.py': 'update_simple_stats'},
          cmdclass={'install': FredWhoisInstall})


if __name__ == '__main__':
    main()
